--
-- Current Database: zm
--

CREATE DATABASE /*!32312 IF NOT EXISTS*/ zm;

USE zm;

--
-- Table structure for table `Config`
--

CREATE TABLE Config (
  Id smallint(5) unsigned NOT NULL default '0',
  Name varchar(32) NOT NULL default '',
  Value text NOT NULL,
  Type tinytext NOT NULL,
  DefaultValue tinytext,
  Hint tinytext,
  Pattern tinytext,
  Format tinytext,
  Prompt tinytext,
  Help text,
  Category varchar(32) NOT NULL default '',
  Readonly tinyint(3) unsigned NOT NULL default '0',
  Requires text,
  PRIMARY KEY  (Name),
  UNIQUE KEY UC_Name (Name)
) TYPE=MyISAM;

--
-- Table structure for table `Events`
--

CREATE TABLE Events (
  Id int(10) unsigned NOT NULL auto_increment,
  MonitorId int(10) unsigned NOT NULL default '0',
  Name varchar(64) NOT NULL,
  Cause varchar(32) NOT NULL default '',
  StartTime datetime default NULL,
  EndTime datetime default NULL,
  Length decimal(10,2) NOT NULL default '0.00',
  Frames int(10) unsigned default NULL,
  AlarmFrames int(10) unsigned default NULL,
  TotScore int(10) unsigned NOT NULL default '0',
  AvgScore smallint(5) unsigned default '0',
  MaxScore smallint(5) unsigned default '0',
  Archived tinyint(3) unsigned NOT NULL default '0',
  Uploaded tinyint(3) unsigned NOT NULL default '0',
  Emailed tinyint(3) unsigned NOT NULL default '0',
  Messaged tinyint(3) unsigned NOT NULL default '0',
  Executed tinyint(3) unsigned NOT NULL default '0',
  LearnState char(1) default '',
  Notes tinytext,
  PRIMARY KEY  (Id),
  UNIQUE KEY UC_Id (Id),
  KEY Id (Id,MonitorId),
  KEY MonitorId (MonitorId),
  KEY StartTime (StartTime),
  KEY Frames (Frames),
  KEY Archived (Archived)
) TYPE=MyISAM;

--
-- Table structure for table `Filters`
--

CREATE TABLE Filters (
  Name varchar(64) NOT NULL,
  Query text NOT NULL,
  AutoArchive tinyint(3) unsigned NOT NULL default '0',
  AutoDelete tinyint(3) unsigned NOT NULL default '0',
  AutoUpload tinyint(3) unsigned NOT NULL default '0',
  AutoEmail tinyint(3) unsigned NOT NULL default '0',
  AutoMessage tinyint(3) unsigned NOT NULL default '0',
  AutoExecute tinytext,
  PRIMARY KEY  (Name)
) TYPE=MyISAM;

--
-- Table structure for table `Frames`
--

CREATE TABLE Frames (
  Id int(10) unsigned NOT NULL auto_increment,
  EventId int(10) unsigned NOT NULL default '0',
  FrameId int(10) unsigned NOT NULL default '0',
  Type enum('Normal','Bulk','Alarm') NOT NULL default 'Normal',
  TimeStamp timestamp(14) NOT NULL,
  Delta decimal(8,2) NOT NULL default '0.00',
  Score smallint(5) unsigned NOT NULL default '0',
  PRIMARY KEY  (Id),
  UNIQUE KEY UC_Id (Id),
  KEY EventId (EventId)
) TYPE=MyISAM;

--
-- Table structure for table `Groups`
--

CREATE TABLE Groups (
  Id int(10) unsigned NOT NULL auto_increment,
  Name varchar(64) NOT NULL,
  MonitorIds tinytext NOT NULL,
  PRIMARY KEY  (Id)
) TYPE=MyISAM;

--
-- Table structure for table `Monitors`
--

CREATE TABLE Monitors (
  Id int(10) unsigned NOT NULL auto_increment,
  Name varchar(64) NOT NULL,
  Type enum('Local','Remote') NOT NULL default 'Local',
  Function enum('None','Monitor','Modect','Record','Mocord','Nodect') NOT NULL default 'Monitor',
  RunMode enum('Continuous','Triggered') NOT NULL default 'Continuous',
  Triggers set('X10') NOT NULL default '',
  Device tinyint(3) unsigned NOT NULL default '0',
  Channel tinyint(3) unsigned NOT NULL default '0',
  Format tinyint(3) unsigned NOT NULL default '0',
  Host varchar(64) default NULL,
  Port varchar(8) default '80',
  Path varchar(255) default NULL,
  Width smallint(5) unsigned NOT NULL default '0',
  Height smallint(5) unsigned NOT NULL default '0',
  Palette tinyint(3) unsigned NOT NULL default '1',
  Orientation enum('0','90','180','270','hori','vert') NOT NULL default '0',
  Brightness mediumint(7) NOT NULL default '-1',
  Contrast mediumint(7) NOT NULL default '-1',
  Hue mediumint(7) NOT NULL default '-1',
  Colour mediumint(7) NOT NULL default '-1',
  EventPrefix varchar(32) NOT NULL default 'Event-',
  LabelFormat varchar(32) NOT NULL default '%%s - %y/%m/%d %H:%M:%S',
  LabelX smallint(5) unsigned default NULL,
  LabelY smallint(5) unsigned default NULL,
  ImageBufferCount smallint(5) unsigned NOT NULL default '100',
  WarmupCount smallint(5) unsigned NOT NULL default '25',
  PreEventCount smallint(5) unsigned NOT NULL default '10',
  PostEventCount smallint(5) unsigned NOT NULL default '10',
  AlarmFrameCount smallint(5) unsigned NOT NULL default '1',
  SectionLength int(10) unsigned NOT NULL default '600',
  FrameSkip smallint(5) unsigned NOT NULL default '0',
  MaxFPS decimal(5,2) NOT NULL default '0.00',
  FPSReportInterval smallint(5) unsigned NOT NULL default '250',
  RefBlendPerc tinyint(3) unsigned NOT NULL default '10',
  Controllable tinyint(3) unsigned NOT NULL default '0',
  ControlId int(10) unsigned NOT NULL default '0',
  ControlDevice varchar(255) default NULL,
  ControlAddress varchar(255) default NULL,
  AutoStopTimeout decimal(5,2) default NULL,
  TrackMotion tinyint(3) unsigned NOT NULL default '0',
  TrackDelay smallint(5) unsigned NOT NULL default '0',
  ReturnLocation tinyint(3) NOT NULL default '-1',
  ReturnDelay smallint(5) unsigned NOT NULL default '0',
  PRIMARY KEY  (Id)
) TYPE=MyISAM;

--
-- Table structure for table `States`
--

CREATE TABLE States (
  Name varchar(64) NOT NULL,
  Definition tinytext NOT NULL,
  PRIMARY KEY  (Name)
) TYPE=MyISAM;

--
-- Table structure for table `Stats`
--

CREATE TABLE Stats (
  MonitorId int(10) unsigned NOT NULL default '0',
  ZoneId int(10) unsigned NOT NULL default '0',
  EventId int(10) unsigned NOT NULL default '0',
  FrameId int(10) unsigned NOT NULL default '0',
  AlarmPixels int(10) unsigned NOT NULL default '0',
  FilterPixels int(10) unsigned NOT NULL default '0',
  BlobPixels int(10) unsigned NOT NULL default '0',
  Blobs smallint(5) unsigned NOT NULL default '0',
  MinBlobSize int(10) unsigned NOT NULL default '0',
  MaxBlobSize int(10) unsigned NOT NULL default '0',
  MinX smallint(5) unsigned NOT NULL default '0',
  MaxX smallint(5) unsigned NOT NULL default '0',
  MinY smallint(5) unsigned NOT NULL default '0',
  MaxY smallint(5) unsigned NOT NULL default '0',
  Score smallint(5) unsigned NOT NULL default '0',
  KEY EventId (EventId),
  KEY MonitorId (MonitorId),
  KEY ZoneId (ZoneId)
) TYPE=MyISAM;

--
-- Table structure for table `TriggersX10`
--

CREATE TABLE TriggersX10 (
  MonitorId int(10) unsigned NOT NULL default '0',
  Activation varchar(32) default NULL,
  AlarmInput varchar(32) default NULL,
  AlarmOutput varchar(32) default NULL,
  PRIMARY KEY  (MonitorId)
) TYPE=MyISAM;

--
-- Table structure for table `Users`
--

CREATE TABLE Users (
  Id int(10) unsigned NOT NULL auto_increment,
  Username varchar(32) BINARY NOT NULL default '',
  Password varchar(64) NOT NULL default '',
  Language varchar(8) NOT NULL default '',
  Enabled tinyint(3) unsigned NOT NULL default '1',
  Stream enum('None','View') NOT NULL default 'None',
  Events enum('None','View','Edit') NOT NULL default 'None',
  Monitors enum('None','View','Edit') NOT NULL default 'None',
  System enum('None','View','Edit') NOT NULL default 'None',
  MonitorIds tinytext,
  PRIMARY KEY  (Id),
  UNIQUE KEY UC_Username (Username),
  UNIQUE KEY UC_Id (Id)
) TYPE=MyISAM;

--
-- Table structure for table `Zones`
--

CREATE TABLE Zones (
  Id int(10) unsigned NOT NULL auto_increment,
  MonitorId int(10) unsigned NOT NULL default '0',
  Name varchar(64) NOT NULL default '',
  Type enum('Active','Inclusive','Exclusive','Preclusive','Inactive') NOT NULL default 'Active',
  Units enum('Pixels','Percent') NOT NULL default 'Pixels',
  LoX smallint(5) unsigned NOT NULL default '0',
  LoY smallint(5) unsigned NOT NULL default '0',
  HiX smallint(5) unsigned NOT NULL default '0',
  HiY smallint(5) unsigned NOT NULL default '0',
  AlarmRGB int(10) unsigned default NULL,
  CheckMethod enum('AlarmedPixels','FilteredPixels','Blobs') NOT NULL default 'Blobs',
  MinPixelThreshold smallint(5) unsigned default NULL,
  MaxPixelThreshold smallint(5) unsigned default NULL,
  MinAlarmPixels int(10) unsigned default NULL,
  MaxAlarmPixels int(10) unsigned default NULL,
  FilterX tinyint(3) unsigned default NULL,
  FilterY tinyint(3) unsigned default NULL,
  MinFilterPixels int(10) unsigned default NULL,
  MaxFilterPixels int(10) unsigned default NULL,
  MinBlobPixels int(10) unsigned default NULL,
  MaxBlobPixels int(10) unsigned default NULL,
  MinBlobs smallint(5) unsigned default NULL,
  MaxBlobs smallint(5) unsigned default NULL,
  PRIMARY KEY  (Id),
  UNIQUE KEY UC_Id (Id)
) TYPE=MyISAM;

--
-- Table structure for table `Controls`
--

CREATE TABLE Controls (
  Id int(10) unsigned NOT NULL auto_increment,
  Name varchar(64) NOT NULL default '',
  Type enum('Local','Remote') NOT NULL default 'Local',
  Command varchar(255) default NULL,

  CanWake tinyint(3) unsigned NOT NULL default '0',
  CanSleep tinyint(3) unsigned NOT NULL default '0',
  CanReset tinyint(3) unsigned NOT NULL default '0',

  CanZoom tinyint(3) unsigned NOT NULL default '0',
  CanAutoZoom tinyint(3) unsigned NOT NULL default '0',
  CanZoomAbs tinyint(3) unsigned NOT NULL default '0',
  CanZoomRel tinyint(3) unsigned NOT NULL default '0',
  CanZoomCon tinyint(3) unsigned NOT NULL default '0',
  MinZoomRange int(10) unsigned default NULL,
  MaxZoomRange int(10) unsigned default NULL,
  MinZoomStep int(10) unsigned default NULL,
  MaxZoomStep int(10) unsigned default NULL,
  HasZoomSpeed tinyint(3) unsigned NOT NULL default '0',
  MinZoomSpeed int(10) unsigned default NULL,
  MaxZoomSpeed int(10) unsigned default NULL,

  CanFocus tinyint(3) unsigned NOT NULL default '0',
  CanAutoFocus tinyint(3) unsigned NOT NULL default '0',
  CanFocusAbs tinyint(3) unsigned NOT NULL default '0',
  CanFocusRel tinyint(3) unsigned NOT NULL default '0',
  CanFocusCon tinyint(3) unsigned NOT NULL default '0',
  MinFocusRange int(10) unsigned default NULL,
  MaxFocusRange int(10) unsigned default NULL,
  MinFocusStep int(10) unsigned default NULL,
  MaxFocusStep int(10) unsigned default NULL,
  HasFocusSpeed tinyint(3) unsigned NOT NULL default '0',
  MinFocusSpeed int(10) unsigned default NULL,
  MaxFocusSpeed int(10) unsigned default NULL,

  CanIris tinyint(3) unsigned NOT NULL default '0',
  CanAutoIris tinyint(3) unsigned NOT NULL default '0',
  CanIrisAbs tinyint(3) unsigned NOT NULL default '0',
  CanIrisRel tinyint(3) unsigned NOT NULL default '0',
  CanIrisCon tinyint(3) unsigned NOT NULL default '0',
  MinIrisRange int(10) unsigned default NULL,
  MaxIrisRange int(10) unsigned default NULL,
  MinIrisStep int(10) unsigned default NULL,
  MaxIrisStep int(10) unsigned default NULL,
  HasIrisSpeed tinyint(3) unsigned NOT NULL default '0',
  MinIrisSpeed int(10) unsigned default NULL,
  MaxIrisSpeed int(10) unsigned default NULL,

  CanGain tinyint(3) unsigned NOT NULL default '0',
  CanAutoGain tinyint(3) unsigned NOT NULL default '0',
  CanGainAbs tinyint(3) unsigned NOT NULL default '0',
  CanGainRel tinyint(3) unsigned NOT NULL default '0',
  CanGainCon tinyint(3) unsigned NOT NULL default '0',
  MinGainRange int(10) unsigned default NULL,
  MaxGainRange int(10) unsigned default NULL,
  MinGainStep int(10) unsigned default NULL,
  MaxGainStep int(10) unsigned default NULL,
  HasGainSpeed tinyint(3) unsigned NOT NULL default '0',
  MinGainSpeed int(10) unsigned default NULL,
  MaxGainSpeed int(10) unsigned default NULL,

  CanWhite tinyint(3) unsigned NOT NULL default '0',
  CanAutoWhite tinyint(3) unsigned NOT NULL default '0',
  CanWhiteAbs tinyint(3) unsigned NOT NULL default '0',
  CanWhiteRel tinyint(3) unsigned NOT NULL default '0',
  CanWhiteCon tinyint(3) unsigned NOT NULL default '0',
  MinWhiteRange int(10) unsigned default NULL,
  MaxWhiteRange int(10) unsigned default NULL,
  MinWhiteStep int(10) unsigned default NULL,
  MaxWhiteStep int(10) unsigned default NULL,
  HasWhiteSpeed tinyint(3) unsigned NOT NULL default '0',
  MinWhiteSpeed int(10) unsigned default NULL,
  MaxWhiteSpeed int(10) unsigned default NULL,

  HasPresets tinyint(3) unsigned NOT NULL default '0',
  NumPresets tinyint(3) unsigned NOT NULL default '0',
  HasHomePreset tinyint(3) unsigned NOT NULL default '0',
  CanSetPresets tinyint(3) unsigned NOT NULL default '0',

  CanMove tinyint(3) unsigned NOT NULL default '0',
  CanMoveDiag tinyint(3) unsigned NOT NULL default '0',
  CanMoveMap tinyint(3) unsigned NOT NULL default '0',
  CanMoveAbs tinyint(3) unsigned NOT NULL default '0',
  CanMoveRel tinyint(3) unsigned NOT NULL default '0',
  CanMoveCon tinyint(3) unsigned NOT NULL default '0',
  CanPan tinyint(3) unsigned NOT NULL default '0',
  MinPanRange int(10) default NULL,
  MaxPanRange int(10) default NULL,
  MinPanStep int(10) default NULL,
  MaxPanStep int(10) default NULL,
  HasPanSpeed tinyint(3) unsigned NOT NULL default '0',
  MinPanSpeed int(10) default NULL,
  MaxPanSpeed int(10) default NULL,
  HasTurboPan tinyint(3) unsigned NOT NULL default '0',
  TurboPanSpeed int(10) default NULL,
  CanTilt tinyint(3) unsigned NOT NULL default '0',
  MinTiltRange int(10) default NULL,
  MaxTiltRange int(10) default NULL,
  MinTiltStep int(10) default NULL,
  MaxTiltStep int(10) default NULL,
  HasTiltSpeed tinyint(3) unsigned NOT NULL default '0',
  MinTiltSpeed int(10) default NULL,
  MaxTiltSpeed int(10) default NULL,
  HasTurboTilt tinyint(3) unsigned NOT NULL default '0',
  TurboTiltSpeed int(10) default NULL,

  CanAutoScan tinyint(3) unsigned NOT NULL default '0',
  NumScanPaths tinyint(3) unsigned NOT NULL default '0',

  PRIMARY KEY  (Id),
  UNIQUE KEY UC_Id (Id)
) TYPE=MyISAM;


--
-- Create a default admin user.
--
insert into Users values ('','admin',password('admin'),'',1,'View','Edit','Edit','Edit',NULL);
--
-- Add in a sample filter to purge the oldest 5 events when the disk is 99% full, delete is disabled though
--
insert into Filters values ('PurgeWhenFull','trms=2&obr1=&cbr1=&attr1=Archived&op1=&val1=0&cnj2=and&obr2=&cbr2=&attr2=DiskPercent&op2=>=&val2=99&sort_field=Id&sort_asc=1&limit=5',0,0,0,0,0,'');
--
-- Add in some sample control protocol definitions
--
insert into Controls values (1,'PELCO-D','Local','/usr/bin/zmcontrol-pelco-d.pl',1,1,0,1,1,0,0,1,NULL,NULL,NULL,NULL,1,0,3,1,1,0,0,1,NULL,NULL,NULL,NULL,0,NULL,NULL,1,1,0,1,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,1,1,0,1,0,NULL,NULL,NULL,NULL,0,NULL,NULL,1,20,1,1,1,1,0,0,0,1,1,NULL,NULL,NULL,NULL,1,0,63,1,254,1,NULL,NULL,NULL,NULL,1,0,63,1,254,0,0);
insert into Controls values (2,'PELCO-P','Local','/usr/bin/zmcontrol-pelco-p.pl',1,1,0,1,1,0,0,1,NULL,NULL,NULL,NULL,1,0,3,1,1,0,0,1,NULL,NULL,NULL,NULL,0,NULL,NULL,1,1,0,1,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,1,1,0,1,0,NULL,NULL,NULL,NULL,0,NULL,NULL,1,20,1,1,1,1,0,0,0,1,1,NULL,NULL,NULL,NULL,1,0,63,1,254,1,NULL,NULL,NULL,NULL,1,0,63,1,254,0,0);
insert into Controls values (3,'Sony VISCA','Local','/usr/bin/zmcontrol-visca.pl',1,1,0,1,0,0,0,1,0,16384,10,4000,1,1,6,1,1,1,0,1,0,1536,NULL,NULL,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,1,3,1,1,1,1,0,1,1,0,1,-15578,15578,100,10000,1,1,50,1,254,1,-7789,7789,100,5000,1,1,50,1,254,0,0);
INSERT INTO Controls VALUES (4,'Axis API v2','Remote','/usr/bin/zmcontrol-axis-v2.pl',0,0,0,1,0,0,1,0,0,9999,10,2500,0,NULL,NULL,1,1,0,1,0,0,9999,10,2500,0,NULL,NULL,1,1,0,1,0,0,9999,10,2500,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,1,12,1,1,1,1,1,0,1,0,1,-360,360,1,90,0,NULL,NULL,0,NULL,1,-360,360,1,90,0,NULL,NULL,0,NULL,0,0);
insert into Controls values (5,'KX-HCM10','Remote','/usr/bin/zmcontrol-kx-hcm10.pl',0,0,0,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,0,0,0,0,0,NULL,NULL,NULL,NULL,0,NULL,NULL,1,8,1,1,1,0,1,0,0,1,1,NULL,NULL,NULL,NULL,0,NULL,NULL,0,NULL,1,NULL,NULL,NULL,NULL,0,NULL,NULL,0,NULL,0,0);

